@@ -1,27 +1,21 @@
-#' Make a regex exact
-#'
-#' Makes a regex exact: that is, it must contain the whole string, not just part
-#' of it.
-#' @param x A character vector.
-#' @return A character vector representing part or all of a regular expression.
-#' @examples
-#' # A hex color
-#' (rx <- "#" %R% hex_digit(6))
-#' (rx_exact <- exactly(rx))
-#'
-#' # Usage
-#' stringi::stri_detect_regex("ginger is #B06500", rx)
-#' stringi::stri_detect_regex("ginger is #B06500", rx_exact)
-#' stringi::stri_detect_regex("#B06500", rx_exact)
+#' @rdname Anchors
 #' @export
 exactly <- function(x)
 {
   regex(START, x, END)
 }
 
-#' Treat part of a regular expression literally.
+#' @rdname WordBoundaries
+#' @export
+whole_word <- function(x)
+{
+  regex(BOUNDARY, x, BOUNDARY)
+}
+
+#' Treat part of a regular expression literally
 #'
-#' Treats its contents as literal characters.
+#' Treats its contents as literal characters. Equivalent to using
+#' \code{fixed = TRUE}, but for part of the pattern rather than all of it.
 #' @param x A character vector.
 #' @return A character vector representing part or all of a regular expression.
 #' @examples
